@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Module::cpmfile::Prereqs;
 use Module::cpmfile::Util qw(merge_version _yaml_hash);
@@ -24,11 +24,7 @@ sub new {
         my $prereqs = Module::cpmfile::Prereqs->new($hash->{features}{$id}{prereqs});
         $feature{$id} = { description => $description, prereqs => $prereqs };
     }
-    bless {
-        prereqs => $prereqs,
-        features => \%feature,
-        _mirrors => [],
-    }, $class;
+    bless { prereqs => $prereqs, features => \%feature, _mirrors => [] }, $class;
 }
 
 sub from_cpanfile {
@@ -54,6 +50,19 @@ sub from_cpanfile {
     bless { prereqs => $prereqs, features => \%feature, _mirrors => $mirrors }, $class;
 }
 
+sub from_cpanmeta {
+    my ($class, $cpanmeta) = @_;
+    my %feature;
+    for my $id (keys %{$cpanmeta->optional_features}) {
+        my $f = $cpanmeta->optional_features->{$id};
+        my $description = $f->{description};
+        my $prereqs = Module::cpmfile::Prereqs->from_cpanmeta($f->{prereqs});
+        $feature{$id} = { description => $description, prereqs => $prereqs };
+    }
+    my $prereqs = Module::cpmfile::Prereqs->from_cpanmeta($cpanmeta->prereqs);
+    bless { prereqs => $prereqs, features => \%feature, _mirrors => [] }, $class;
+}
+
 sub prereqs {
     my $self = shift;
     $self->{prereqs};
